<?php
/**
 * @name Model_Report
 * @description Classe modèle Report
 *		Toutes les méthodes d'acces à la BD pour les tables concernant le Report
 * @author Victor Marin <v.marin@esia-sa.com>
 * @date 14/02/2017
 */
include_once MVCMODEL;
class Model_Report extends Model_esia
{
	public const BYSERVICE=1;
	public const BYNODE=2;
	public const BYGROUP=2;
	/**@NAME: getBlockAvailable
	 *@IN: $dbconnection l'objet de connexion PDO
	 *     $Canevas_Id contenant l'identifiant du canevas
	 *@OUT: Les report block qui ne sont pas correspondant avec le canevas
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function getBlockAvailable($dbconnection,$Canevas_Id)
	{
		$sql = "SELECT block_id,block_name,block_controller
				FROM   report_block
				WHERE  block_id not in (SELECT include_block_id
										FROM report_include_block
										WHERE include_canevas_id =:id)";

		$query= $dbconnection->prepare($sql);
		$query = Model_esia::executeStatement($query,array(':id' =>$Canevas_Id));

		$report=array();
		while($row=$query->fetch(PDO::FETCH_OBJ))
		{
			$report[]=array('block_id'=>$row->block_id,
					'block_name'=>$row->block_name,
					'block_controller'=>$row->block_controller,
			);
		}
		return $report;
	}

	/**@NAME: getAllBlockOfCanevas
	 *@IN: $dbconnection l'objet de connexion PDO
	 *     $Canevas_Id contenant l'identifiant du canevas
	 *@OUT: Les report block correspondant au canevas dans l'ordre des positions de Report_Include_Block
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function getAllBlockOfCanevas($dbconnection,$Canevas_Id)
	{
		$sql = " SELECT report_canevas.canevas_name, report_block.block_id, report_block.block_name,report_block.block_controller, report_include_block.include_position, report_include_block.include_id,report_include_block.include_parameter
			  	 FROM report_block
				 JOIN report_include_block ON include_block_id = block_id
				 JOIN report_canevas ON canevas_id = include_canevas_id
				 WHERE canevas_id = :id
				 ORDER BY report_include_block.include_position";

		$query= $dbconnection->prepare($sql);
		$query = Model_esia::executeStatement($query,array(':id' =>$Canevas_Id));

		$report=array();
		while($row=$query->fetch(PDO::FETCH_OBJ))
		{
			$report[]=array('block_id'=>$row->block_id,
					'block_name'=>$row->block_name,
					'block_controller'=>$row->block_controller,
					'include_position'=>$row->include_position,
					'canevas_name'=>$row->canevas_name,
					'include_id'=>$row->include_id,
					'include_parameter'=>$row->include_parameter,
			);
		}
		return $report;
	}
	public static function getNodeBasicInformation($dbconnection,$ids,$type=Model_Report::BYNODE)
	{
		$sql ="SELECT t2.device_group_name,device_id,device_name,device_description,device_ip_address,device_type
			FROM esia_device
			LEFT JOIN esia_device_group_in ON device_id= group_in_device_id
			LEFT JOIN esia_device_group as t2 ON  group_in_device_group_id = device_group_id
			WHERE";
		$columns = 'device_id';
		if($type == Model_Report::BYGROUP)
		{
			$columns = 'device_group_id';
		}
		
		if(!is_array($ids))
		{
			$sql .= " $columns = :dataid";
			$params[':dataid'] = $ids;
		}
		else
		{
			$i = 0;
			$sql_prepare_arr='';
			foreach($ids as $sr_id)
			{
				$params[':dataid'.$i]=$sr_id;
				$sql_prepare_arr .= ':dataid'.$i.',';
				$i++;
			}
			$sql_prepare_arr= rtrim($sql_prepare_arr,',');
			$sql .= " $columns IN ($sql_prepare_arr)";
		}
		
	}
	/**@NAME: getUsageRessourceNode
	 *@IN: $dbconnection l'objet de connexion PDO
	 *     $nodeId contenant l'identifiant du canevas
	 *@OUT: Les report block correspondant au canevas dans l'ordre des positions de Report_Include_Block
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function getUsageRessourceNode($dbconnection,$nodeId)
	{
		if(is_numeric($nodeId))
		{
			$sql = "SELECT service_device_id,service_name, service_parameter,plugin_name, service_id,service_last_stdout
					FROM esia_services
					JOIN esia_plugins ON plugin_id=service_plugin_id
					WHERE service_device_id = :Noeud_id
					AND plugin_name IN ( SELECT plugin_name
									 	FROM esia_services
									 	WHERE plugin_name LIKE '%LOAD%'
									 	OR plugin_name LIKE '%MEM%'
									 	OR plugin_name LIKE '%STORAGE%'
									 	OR plugin_name LIKE '%RAM%'
										OR plugin_name LIKE '%CPU%')";
		}
		else
		{

			$sql = "SELECT service_device_id,service_name, service_parameter,plugin_name, service_id,service_last_stdout
					FROM esia_services
					JOIN esia_plugins ON plugin_id=service_plugin_id
					JOIN esia_device ON device_id = service_device_id
					JOIN esia_device_group_in ON device_id= group_in_device_id
					JOIN esia_device_group as t2 ON  group_in_device_group_id = device_group_id
					WHERE device_name = :Noeud_id
					AND plugin_name IN ( SELECT plugin_name
									 	FROM esia_services
									 	WHERE plugin_name LIKE '%LOAD%'
									 	OR plugin_name LIKE '%MEM%'
									 	OR plugin_name LIKE '%STORAGE%'
									 	OR plugin_name LIKE '%RAM%')";
		}

		$query= $dbconnection->prepare($sql);
		$query = Model_esia::executeStatement($query,array(':Noeud_id' =>$nodeId));

		$arr=array();
	 	while($row=$query->fetch(PDO::FETCH_OBJ))
	 	{
	 		$arr[]=array(
	 			'service_name'=>$row->service_name,
	 				'plugin_name'=>$row->plugin_name,
	 				'service_id'=>$row->service_id,
	 				'service_parameter'=>$row->service_parameter,
	 				'service_last_stdout'=>$row->service_last_stdout,
	 	 	);
	 	}
	 	return $arr;
	}
	/**
	 *récupère les donnée pour le blocks des incidents
	 *@param: PDO $dbconnection l'objet de connexion PDO
	 *     date $start date contenant date_next_generate - interval
	 *     date $end date contenant date_next_generate
	 *     array|integer $ids l'identifiant du service ou du noeud
	 *     integer $type  constante spécifiant si l'id est un service_id (Model_Report::BYSERVICE) ou un device_id (Model_Report::BYNODE)
     *     string $filter default('warning,critical') filtre les erreurs par le niveau demandé (error_type) séparé par des virgules
	 *@retval: Les report includes block et les report_block correspondant au canevas
	 *@throws: 	EsiaDbException si une erreur survient
	 */
	public static function getRepportIncidentBlock($dbconnection,$start,$end,$ids,$type=Model_Report::BYSERVICE,$filter='warning,critical')
	{
		 $sql = " SELECT device_name,device_description,service_name, 
                         plugin_name,device_ip_address,error_type, happen_message, to_char(happen_timestamp,'DD-MM-YYYY HH24:MI:SS') as time ,
                        to_char(happen_time_acquitte,'DD-MM-YYYY HH24:MI:SS') as time_end, 
                        to_char((happen_time_acquitte - happen_timestamp),'DDD HH24:MI:SS') as during,
                        EXTRACT(EPOCH FROM (happen_time_acquitte - happen_timestamp))::integer as during_in_second,
                        t2.device_group_name
	 			  FROM esia_error_happen
	 		      JOIN esia_errors ON error_id = happen_error_id
	 			  JOIN esia_device ON device_id = happen_device_id
	 			  LEFT JOIN esia_device_group_in ON happen_device_id= group_in_device_id
	 			  LEFT JOIN esia_device_group as t2 ON  group_in_device_group_id = device_group_id
	 			  JOIN esia_services ON service_id = happen_service_id
		 		  JOIN esia_plugins ON plugin_id = service_plugin_id
	 			  WHERE (happen_timestamp > :start AND happen_timestamp <  :end)";
        $params = array(':start' =>$start,
                        ':end'=>$end);
        $columns = 'happen_service_id';    
        if($type == Model_Report::BYNODE)
        {
            $columns = 'happen_device_id';  
        }
        if(!is_array($ids))
        {
            $sql .= " AND $columns = :dataid";
            $params[':dataid'] = $ids;
        }
        else
        {
            $i = 0;
            $sql_prepare_arr='';
            foreach($ids as $sr_id)
            {
                $params[':dataid'.$i]=$sr_id;
                $sql_prepare_arr .= ':dataid'.$i.',';
                $i++;
            }
            $sql_prepare_arr= rtrim($sql_prepare_arr,',');
            $sql .= " AND $columns IN ($sql_prepare_arr)";
        }
        $error_type = explode(',',$filter);
        $i = 0;
        $sql_prepare_arr='';
        foreach($error_type as $err)
        {
            $params[':error'.$i]=$err;
            $sql_prepare_arr .= ':error'.$i.',';
            $i++;
        }
        $sql_prepare_arr= rtrim($sql_prepare_arr,',');
        $sql .= " AND error_type IN ($sql_prepare_arr)";       
        $sql .= " ORDER BY happen_timestamp ASC";
        //echo $sql;
        //print_r($params);
        $query= $dbconnection->prepare($sql);
        $query = Model_esia::executeStatement($query,$params);
        $arr=array();
        while($row=$query->fetch(PDO::FETCH_OBJ))
        {
            $arr[]=array(
				'device_name'=>$row->device_name,
				'service_name'=>$row->service_name,
				'description'=>$row->device_description,
				'error_type'=>$row->error_type,
				'happen_message'=>$row->happen_message,
				'time'=>$row->time,
				'time_end'=>$row->time_end,
				'during'=>$row->during,
            	'during_second'=>$row->during_in_second,
				'plugin_name'=>$row->plugin_name,
				'ip'=>$row->device_ip_address,
				'group_name'=>$row->device_group_name,
            );
        }
        return $arr;
	}

	/**@NAME: getEsiaErrorServiceId
	 *@IN: $dbconnection l'objet de connexion PDO
	 *     $Service_id contenant l'identifiant du service
	 *     $Start date contenant date_next_generate - interval
	 *     $End date contenant date_next_generate
	 *@OUT: Les report includes block et les report_block correspondant au canevas
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function getEsiaErrorServiceId($dbconnection,$Service_id,$Start,$End)
	{
		 $sql = " SELECT device_name,device_description,service_name, 
                         plugin_name,device_ip_address,error_type, happen_message, to_char(happen_timestamp,'DD-MM-YYYY HH24:MI:SS') as time ,
                        to_char(happen_time_acquitte,'DD-MM-YYYY HH24:MI:SS') as time_end, 
                        to_char((happen_time_acquitte - happen_timestamp),'DDD HH24:MI:SS') as during,t2.device_group_name
	 			  FROM esia_error_happen
	 		      JOIN esia_errors ON error_id = happen_error_id
	 			  JOIN esia_device ON device_id = happen_device_id
	 			  LEFT JOIN esia_device_group_in ON happen_device_id= group_in_device_id
	 			  LEFT JOIN esia_device_group as t2 ON  group_in_device_group_id = device_group_id
	 			  JOIN esia_services ON service_id = happen_service_id
		 		  JOIN esia_plugins ON plugin_id = service_plugin_id
	 			  WHERE (happen_timestamp > :DateDebut AND happen_timestamp <  :DateFin)";
        $params = array(':DateDebut' =>$Start,
                        ':DateFin'=>$End);
        if(!is_array($Service_id))
        {
            $sql .= " AND happen_service_id=:service_id";
            $params[':service_id'] = $Service_id;
        }
        else
        {
            $i = 0;
            $sql_prepare_arr='';
            foreach($Service_id as $sr_id)
            {
                $params[':service_id'.$i]=$sr_id;
                $sql_prepare_arr .= ':service_id'.$i.',';
                $i++;
            }
            $sql_prepare_arr= rtrim($sql_prepare_arr,',');
            $sql .= " AND happen_service_id IN ($sql_prepare_arr)";
        }
        $sql .= " ORDER BY happen_timestamp ASC";
		 $query= $dbconnection->prepare($sql);
	 	 $query = Model_esia::executeStatement($query,$params);
	 	 $Response=array();
	 	 while($row=$query->fetch(PDO::FETCH_OBJ))
	 	 {
	 	 	$Response[]=array(
				'device_name'=>$row->device_name,
				'service_name'=>$row->service_name,
				'description'=>htmlEntities($row->device_description, ENT_QUOTES),
				'error_type'=>$row->error_type,
				'happen_message'=>$row->happen_message,
				'time'=>$row->time,
				'time_end'=>$row->time_end,
				'during'=>$row->during,
				'plugin_name'=>$row->plugin_name,
				'device_ip_addr'=>$row->device_ip_address,
				'device_group_name'=>$row->device_group_name,
	 	 	);
	 	 }
	 	 return $Response;
	}

	/**@NAME: getEsiaErrorNoeudId
	 *@IN: $dbconnection l'objet de connexion PDO
	 *     $Service_id contenant l'identifiant du service
	 *     $Start date contenant date_next_generate - interval
	 *     $End date contenant date_next_generate
	 *@OUT: Les report includes block et les report_block correspondant au canevas
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function getEsiaErrorNoeudId($dbconnection,$Noeud_id,$Start,$End)
	{
	    //récupération du groupe de noeuds
		$sql = " SELECT t2.device_group_name
	 			 FROM  esia_device_group_in
	 			 JOIN esia_device_group as t2 ON  group_in_device_group_id = device_group_id
	 			 WHERE group_in_device_id=:Noeud_id";
		$query= $dbconnection->prepare($sql);
		$query = Model_esia::executeStatement($query,array(':Noeud_id' =>$Noeud_id));
        	$groupname = "";
    		while($row=$query->fetch(PDO::FETCH_OBJ))
	 	{
            		$groupname.=" ".$row->device_group_name.',';
        	}
        	//supprime la dernière virgule
		$groupname = substr($groupname, 0, -1);
		$sql = " SELECT device_id,device_name,service_name,plugin_name,device_ip_address, error_type, happen_message, to_char(happen_timestamp,'DD-MM-YYYY HH24:MI:SS') as time , to_char(happen_time_acquitte,'DD-MM-YYYY HH24:MI:SS') as time_end,to_char((happen_time_acquitte - happen_timestamp),'DDD HH24:MI:SS') as during
	 			  FROM esia_error_happen
	 		      JOIN esia_errors ON error_id = happen_error_id
	 			  JOIN esia_device ON device_id = happen_device_id
	 			  JOIN esia_services ON service_id = happen_service_id
				  JOIN esia_plugins ON plugin_id = service_plugin_id
	 			  WHERE happen_device_id=:Noeud_id AND (happen_timestamp > :DateDebut AND happen_timestamp <  :DateFin)";

		$query= $dbconnection->prepare($sql);
		$query = Model_esia::executeStatement($query,array(':Noeud_id' =>$Noeud_id,
				':DateDebut' =>$Start,
				':DateFin'=>$End));

		$Response=array();
	 	while($row=$query->fetch(PDO::FETCH_OBJ))
	 	{
	 		$Response[]=array(
				'device_name'=>$row->device_name,
				'device_id' => $row->device_id,
				'service_name'=>$row->service_name,
				'error_type'=>$row->error_type,
				'happen_message'=>$row->happen_message,
				'time'=>$row->time,
				'time_end'=>$row->time_end,
				'during'=>$row->during,
				'plugin_name'=>$row->plugin_name,
				'device_ip_addr'=>$row->device_ip_address,
				'device_group_name'=>$groupname,
	 	 	);
	 	}
	 	return $Response;
	}


	/**@NAME: getReportAll_Include_Block
	 *@IN: $dbconnection l'objet de connexion PDO
	 *     $Canevas_Id contenant l'identifiant du canevas
	 *@OUT: Les report includes block et les report_block correspondant au canevas
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function getReportAll_Include_Block($dbconnection,$Canevas_Id)
	{
		$sql = "SELECT include_block_id, block_controller, include_id
				FROM report_include_block
				JOIN report_block ON block_id = include_block_id
				WHERE include_canevas_id = :id
				ORDER BY include_position;";

		$query = $dbconnection->prepare($sql);
		$query = Model_esia::executeStatement($query,array(':id' =>$Canevas_Id));

		$reportCanevas=array();
		while($row=$query->fetch(PDO::FETCH_OBJ))
		{
			$reportCanevas[]=array('include_block_id'=>$row->include_block_id,
					'include_id'=>$row->include_id,
					'block_controller'=>$row->block_controller,);
		}
		return $reportCanevas;
	}


	// TABLE report_canevas

	/**@NAME: getReportCanevasUser
	 *@IN: $dbconnection l'objet de connexion PDO
	 *	   $id précise l'id de l'utilisateur
	 *@OUT: Les report(s) canevas appartenant à l'utilisateur
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function getReportCanevasUser($dbconnection,$userId)
	{
		$sql = "SELECT canevas_id,canevas_name,canevas_description,canevas_interval,canevas_date_nextgeneration,canevas_parameter, canevas_user_share,canevas_user_writing
				FROM report_canevas
				JOIN report_send_users ON send_canevas_id = canevas_id
				WHERE send_user_id = :id";

		$query = $dbconnection->prepare($sql);
		$query = parent::executeStatement($query,array(':id' =>$userId));

		$reportCanevas=array();
		while($row=$query->fetch(PDO::FETCH_OBJ))
		{
			$reportCanevas[]=array('canevas_id'=>$row->canevas_id,
					'canevas_name'=>$row->canevas_name,
			         'canevas_description'=>htmlEntities($row->canevas_description, ENT_QUOTES),
					'canevas_interval'=>$row->canevas_interval,
					'canevas_date_nextgeneration'=>$row->canevas_date_nextgeneration,
					'canevas_parameter'=>$row->canevas_parameter,
					'canevas_user_share'=>$row->canevas_user_share,
					'canevas_user_writing'=>$row->canevas_user_writing,
			);
		}
		return $reportCanevas;
	}

	/**@NAME: getReportCanevas
	 *@IN: $dbconnection l'objet de connexion PDO
	 *	   $id (optionnelle) précise l'id d'un report canevas en particulier
	 *@OUT: Le report canevas designe
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function getReportCanevas($dbconnection,$id=null)
	{
		$sql='SELECT canevas_id,canevas_name,canevas_description,canevas_interval,canevas_date_nextgeneration,canevas_parameter
											FROM report_canevas';
		$param=array();
		if(!empty($id)&& $id!=null)
		{
			$sql.=' WHERE canevas_id = ?;';
			$param[]=$id;
		}

		$query = $dbconnection->prepare($sql);
		$query = parent::executeStatement($query,$param);

		$reportCanevas=array();
		while($row=$query->fetch(PDO::FETCH_OBJ))
		{
			$reportCanevas[]=array('canevas_id'=>$row->canevas_id,
					'canevas_name'=>$row->canevas_name,
			    'canevas_description'=>htmlEntities($row->canevas_description, ENT_QUOTES),
					'canevas_interval'=>$row->canevas_interval,
					'canevas_date_nextgeneration'=>$row->canevas_date_nextgeneration,
					'canevas_parameter'=>$row->canevas_parameter,
			);
		}
		return $reportCanevas;
	}

	/**@NAME: addReportCanevas
	 *@IN: $dbconnection l'objet de connexion PDO
	 *     $name string contenant le nom du canevas à add dans la BD
	 *     $description string contenant une description du canevas à add dans la BD
	 *     $inter interval contenant l'interval du canevas à add dans la BD
	 *     $date date contenant la date du canevas à add dans la BD
     *@OUT: L'identifiant du report cannevas ajouté
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function addReportCanevas($dbconnection,$name,$description,$inter,$date,$param)
	{
		$query= $dbconnection->prepare("INSERT INTO report_canevas (canevas_name,canevas_description,canevas_interval,canevas_date_nextgeneration,canevas_parameter)
				    					VALUES(:name,:description,:inter::interval,to_date(:date, 'DD/MM/YYYY'),:param) RETURNING canevas_id");

		$query = Model_esia::executeStatement($query,array(':name' =>$name,
														   ':description'=>$description,
														   ':inter'=>$inter,
														   ':date'=>$date,
														   ':param'=>$param));
		$row=$query->fetch(PDO::FETCH_OBJ);
		return $row->canevas_id;
	}

	/**@NAME: delReportCanevas
	 *@IN: $dbconnection l'objet de connexion PDO
	 *     $id serial contenant l'identifiant de l'object reportCanevas à delete dans la BD
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function delReportCanevas($dbconnection,$id)
	{
		if($id!=null)
		{
			$query= $dbconnection->prepare("DELETE FROM report_canevas WHERE canevas_id = :id");
			$query = Model_esia::executeStatement($query,array(':id' =>$id));
		}
	}

	/**@NAME: UpdtReportCanevas
	 *@IN: $dbconnection l'objet de connexion PDO
	 *     $id serial contenant l'identifiant du reportCanevas à update dans la BD
     *     $name (optionnelle) string contenant le nom du reportCanevas à update dans la BD
     *     $descr (optionnelle) string contenant la description du reportCanevas à update dans la BD
     *     $inter (optionnelle) interval contenant l'interval du reportCanevas à update dans la BD
     *     $date (optionnelle) date contenant la date de la generation suivante du reportCanevas à update dans la BD
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function UpdtReportCanevas($dbconnection,$id,$name=null,$descr=null,$inter=null,$date=null,$param=null)
	{
		$sql = "UPDATE report_canevas SET canevas_name=:name,canevas_description=:descr,canevas_interval=:inter::interval,
					canevas_date_nextgeneration = to_date(:date, 'DD/MM/YYYY'),canevas_parameter=:param WHERE canevas_id = :id;";

		$query= $dbconnection->prepare($sql);
		$query = Model_esia::executeStatement($query,array(':id' =>$id,
				':name' =>$name,
				':descr'=>$descr,
				':inter'=>$inter,
				':date'=>$date,
				':param'=>$param));
	}



	// TABLE report_block

	/**@NAME: getReportBlock
	 *@IN: $dbconnection l'objet de connexion PDO
	 *     $id (optionnelle) précise l'id d'un report block en particulier
	 *@OUT: Le report block designe
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function getReportBlock($dbconnection,$id=null,$name=null)
	{
		$sql = "SELECT block_id,block_name,block_controller,block_default_parameter,report_block_group_name
				FROM report_block LEFT OUTER JOIN report_block_group
				ON report_block_group_id=block_group_id";

		$param=array();
		if(!empty($id)&& $id!=null)
		{
			$sql.=' WHERE block_id = ?;';
			$param[]=$id;
		}
		elseif(!empty($name) && $name!=null)
		{
			$sql.=' WHERE block_name = ?;';
			$param[]=$name;
		}

		$query = $dbconnection->prepare($sql);
		$query = parent::executeStatement($query,$param);

		$reportBlock=array();
		while($row=$query->fetch(PDO::FETCH_OBJ))
		{
			$reportBlock[]=array('block_id'=>$row->block_id,
					'block_name'=>$row->block_name,
					'block_group' => $row->report_block_group_name,
					'block_controller'=>$row->block_controller,
					'block_default_parameter'=>$row->block_default_parameter,
			);
		}
		return $reportBlock;
	}

	/**@NAME: addReportBlock
	 *@IN: $dbconnection l'objet de connexion PDO
	 *     $name string contenant le nom du reportBlock à add dans la BD
	 *     $controller string contenant le controller du reportBlock à add dans la BD
	 *     $defaut_parameter json contenant les parameter par defaut du reportBlock à add dans la BD
	 *@OUT: L'identifiant du report block ajouté
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function addReportBlock($dbconnection,$name,$controller,$defaut_parameter)
	{
		$query= $dbconnection->prepare("INSERT INTO report_block (block_name,block_controller,block_default_parameter)
				    					VALUES(:name,:controller,:defaut_parameter) RETURNING block_id");

		$query = Model_esia::executeStatement($query,array(':name' =>$name,
				':controller'=>$controller,
				':defaut_parameter'=>$defaut_parameter));
		$row=$query->fetch(PDO::FETCH_OBJ);
		return $row->block_id;
	}

	/**@NAME: delReportBlock
	 *@IN: $dbconnection l'objet de connexion PDO
	 *     $id serial contenant l'identifiant de l'object reportBlock à delete dans la BD
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function delReportBlock($dbconnection,$id)
	{
		if($id!=null)
		{
			$query= $dbconnection->prepare("DELETE FROM report_block WHERE block_id = :id");
			$query = Model_esia::executeStatement($query,array(':id' =>$id));
		}
	}

	/**@NAME: UpdtReportBlock
	 *@IN: $dbconnection l'objet de connexion PDO
	 *     $id serial contenant l'identifiant du reportBlock  à update dans la BD
     *     $name (optionnelle) string contenant le nom du reportBlock  à update dans la BD
     *     $controller (optionnelle) string contenant le controller du reportBlock  à update dans la BD
     *     $param (optionnelle) json contenant les parameter par defaut du reportBlock  à update dans la BD
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function UpdtReportBlock($dbconnection,$id,$name=null,$controller=null,$param=null)
	{
		$query= $dbconnection->prepare("UPDATE report_block SET block_name=:name,block_controller=:controller,block_default_parameter=:parameter
										WHERE block_id = :id;");

		$query = Model_esia::executeStatement($query,array(':id' =>$id,
				':name' =>$name,
				':controller'=>$controller,
				':parameter'=>$param));
	}



	// TABLE report_include_block

	/**@NAME: getReportIncludeBlock
	 *@IN: $dbconnection l'objet de connexion PDO
	 * 	   $id (optionnelle) précise l'id d'un report include block en particulier
	 * 	   $idBlock (optionnelle) précise l'id du block d'un report include block en particulier
	 * 	   $idCanevas (optionnelle) précise l'id du canevas d'un report include block en particulier
	 *@OUT: Le report include block designe
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function getReportIncludeBlock($dbconnection,$id=null,$idBlock=null,$idCanevas=null)
	{
		$sql = "SELECT include_id,include_block_id,include_canevas_id,include_position,include_parameter
		FROM report_include_block";

		$param=array();
		if(!empty($id)&& $id!=null)
		{
			$sql.=' WHERE include_id = :id';
			if(!empty($idBlock)&& $idBlock!=null)
			{
				$sql.=' AND include_block_id = :idblock';
				if(!empty($idCanevas)&& $idCanevas!=null)
				{
					$sql.=' AND include_canevas_id = :idcanevas';
					$param=array(':id' =>$id,
							':idblock'=>$idBlock,
							':idcanevas'=>$idCanevas);
				}
				else
				{
					$param=array(':id' =>$id,
							':idblock'=>$idBlock);
				}
			}
			else
			{
				if(!empty($idCanevas)&& $idCanevas!=null)
				{
					$sql.=' AND include_canevas_id = :idcanevas';
					$param=array(':id' =>$id,
							':idcanevas'=>$idCanevas);
				}
				else
				{
					$param=array(':id' =>$id);
				}
			}
		}
		else
		{
			if(!empty($idBlock)&& $idBlock!=null)
			{
				$sql.=' WHERE include_block_id = :idblock';
				if(!empty($idCanevas)&& $idCanevas!=null)
				{
					$sql.=' AND include_canevas_id = :idcanevas';
					$param=array(':idblock'=>$idBlock,
							':idcanevas'=>$idCanevas);
				}
				else
				{
					$param=array(':idblock'=>$idBlock);
				}
			}
			else
			{
				if(!empty($idCanevas)&& $idCanevas!=null)
				{
					$sql.=' WHERE include_canevas_id = :idcanevas';
					$param=array(':idcanevas'=>$idCanevas);
				}
			}
		}
		$query = $dbconnection->prepare($sql);
		$query = parent::executeStatement($query,$param);

		$reportIncludeBlock=array();
		while($row=$query->fetch(PDO::FETCH_OBJ))
		{
			$params= json_decode($row->include_parameter,true);	
			$reportIncludeBlock[]=array(
					'include_id'=>$row->include_id,
					'id'=>$row->include_id,
					'name'=>$params['title']['text'],
					'description'=>$params['description']['text'],
					'include_block_id'=>$row->include_block_id,
					'include_canevas_id'=>$row->include_canevas_id,
					'include_position'=>$row->include_position,
					'parameters'=>$params,
			);	
		}
		return $reportIncludeBlock;
	}

	/**@NAME: addReportIncludeBlock
	 *@IN: $dbconnection l'objet de connexion PDO
	 *     $block_id integer contenant l'identifiant du block du report include Block à add dans la BD
	 *     $canevas_id integer contenant l'identifiant du canevas du report include Block à add dans la BD
	 *     $position integer contenant la position du report include Block à add dans la BD
  	 *     $parameter json contenant les parameter du report include Block à add dans la BD
  	 *@OUT: L'identifiant du report include block ajouté
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function addReportIncludeBlock($dbconnection,$block_id,$canevas_id,$position,$parameter)
	{
		$query= $dbconnection->prepare("INSERT INTO report_include_block (include_block_id,include_canevas_id,include_position,include_parameter)
				    					VALUES(:blockId,:canevasId,:position,:parameter) RETURNING include_id");

		$query = Model_esia::executeStatement($query,array(':blockId' =>$block_id,
				':canevasId'=>$canevas_id,
				':position'=>$position,
				':parameter'=>$parameter));
		$row=$query->fetch(PDO::FETCH_OBJ);
		return $row->include_id;

	}

	/**@NAME: delReportIncludeBlock
	 *@IN: $dbconnection l'objet de connexion PDO
	 *     $id serial contenant l'identifiant de l'object reportIncludeBlock à delete dans la BD
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function delReportIncludeBlock($dbconnection,$id,$idBlock=null,$idCanevas=null)
	{
		if($id!=null)
		{
			$query= $dbconnection->prepare("DELETE FROM report_include_block WHERE include_id = :id");
			$query = Model_esia::executeStatement($query,array(':id' =>$id));
		}
		if ($idBlock!=null and $idCanevas!=null)
		{
			$query= $dbconnection->prepare("DELETE FROM report_include_block
											WHERE include_canevas_id = :idcanevas
											AND include_block_id = :idblock ");
			$query = Model_esia::executeStatement($query,array(':idblock' =>$idBlock,
																':idcanevas'=>$idCanevas));
		}
	}

	/**@NAME: UpdtReportIncludeBlock
	 *@IN: $dbconnection l'objet de connexion PDO
	 *     $id serial contenant l'identifiant du reportIncludeBlock  à update dans la BD
     *     $block_id (optionnelle) integer contenant l'identifiant du block du reportIncludeBlock à update dans la BD
     *     $canevas_id (optionnelle) integer contenant l'identifiant du canevas du reportIncludeBlock à update dans la BD
     *     $position (optionnelle) interger contenant la position du reportIncludeBlock à update dans la BD
     *     $param (optionnelle) json contenant les parameters du reportIncludeBlock à update dans la BD
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function UpdtReportIncludeBlock($dbconnection,$id,$block_id=null,$canevas_id=null,$position=null,$param=null)
	{
		$query= $dbconnection->prepare("UPDATE report_include_block SET include_block_id=:block_id,include_canevas_id=:canevas_id,include_position=:position,
				include_parameter=:parameter WHERE include_id = :id;");

		$query = Model_esia::executeStatement($query,array(':id' =>$id,
				':block_id' =>$block_id,
				':canevas_id'=>$canevas_id,
				':position'=>$position,
				':parameter'=>$param));
	}



	// TABLE report

	/**@NAME: getReport_of_ReportCanevas
	 *@IN: $dbconnection l'objet de connexion PDO
	 *	   $id précise l'id du canevas
	 *	   $today (optionnelle) date du jour, pour recupere le rapport le plus recent
	 *@OUT: Le report designe
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function getReport_of_ReportCanevas ($dbconnection,$idCanevas,$today=null)
	{
		$sql = "SELECT id,name,date_generate,path_html,path_pdf,report.canevas_id,report_date_start,report_date_end
				FROM report
				JOIN report_canevas ON report_canevas.canevas_id = report.canevas_id
				WHERE report_canevas.canevas_id = :id";

		if($today!=null)
		{
			$sql .= " AND to_char(report.date_generate,'YYYY-MM-DD') = :date";
			$query = $dbconnection->prepare($sql);
			$query = parent::executeStatement($query,array(':id' =>$idCanevas,':date'=>$today));
		}
		else
		{
			$query = $dbconnection->prepare($sql);
			$query = parent::executeStatement($query,array(':id' =>$idCanevas));
		}

		$reportIncludeBlock=array();
		while($row=$query->fetch(PDO::FETCH_OBJ))
		{
			$reportIncludeBlock[]=array('id'=>$row->id,
					'name'=>$row->name,
					'date_generate'=>$row->date_generate,
					'path_html'=>$row->path_html,
					'path_pdf'=>$row->path_pdf,
					'canevas_id'=>$row->canevas_id,
					'report_date_start'=>$row->report_date_start,
					'report_date_end'=>$row->report_date_end,
			);
		}
		return $reportIncludeBlock;
	}

	/**@NAME: getReportUser
	 *@IN: $dbconnection l'objet de connexion PDO
	 *	   $id précise l'id de l'utilisateur
	 *	   $today (optionnelle) date du jour, pour recupere le rapport le plus recent
	 *@OUT: Le report designe
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function getReportUser ($dbconnection,$idUser,$today=null)
	{
		$sql = "SELECT id,name,date_generate,path_html,path_pdf,report.canevas_id,report_canevas.canevas_name,report_date_start,report_date_end,canevas_user_writing
				FROM report
				JOIN report_canevas ON report_canevas.canevas_id = report.canevas_id
				JOIN report_send_users ON send_canevas_id = report_canevas.canevas_id
				WHERE send_user_id = :id";

		if($today!=null)
		{
			$sql .= " AND to_char(report.date_generate,'YYYY-MM-DD') = :date
					ORDER BY report.date_generate DESC";
			$query = $dbconnection->prepare($sql);
			$query = parent::executeStatement($query,array(':id' =>$idUser,':date'=>$today));
		}
		else
		{
			$sql .= " ORDER BY report.date_generate DESC";
			$query = $dbconnection->prepare($sql);
			$query = parent::executeStatement($query,array(':id' =>$idUser));
		}

		$reportIncludeBlock=array();
		while($row=$query->fetch(PDO::FETCH_OBJ))
		{
			$reportIncludeBlock[]=array('id'=>$row->id,
					'canevas_user_writing'=>$row->canevas_user_writing,
					'canevas_name'=>$row->canevas_name,
					'name'=>$row->name,
					'date_generate'=>$row->date_generate,
					'path_html'=>$row->path_html,
					'path_pdf'=>$row->path_pdf,
					'canevas_id'=>$row->canevas_id,
					'report_date_start'=>$row->report_date_start,
					'report_date_end'=>$row->report_date_end,
			);
		}
		return $reportIncludeBlock;
	}


	/**@NAME: getReport
	 *@IN: $dbconnection l'objet de connexion PDO
	 *	   $id (optionnelle) précise l'id d'un report en particulier
	 *@OUT: Le report designe
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function getReport($dbconnection,$id=null)
	{

		$sql = "SELECT id,name,date_generate,path_html,path_pdf,canevas_id,report_date_start,report_date_end
				FROM report";

		$param=array();
		if(!empty($id)&& $id!=null)
		{
			$sql.=' WHERE id = ?;';
			$param[]=$id;
		}

		$query = $dbconnection->prepare($sql);
		$query = parent::executeStatement($query,$param);

		$reportIncludeBlock=array();
		while($row=$query->fetch(PDO::FETCH_OBJ))
		{

			$reportIncludeBlock[]=array('id'=>$row->id,
					'name'=>$row->name,
					'date_generate'=>$row->date_generate,
					'path_html'=>$row->path_html,
					'path_pdf'=>$row->path_pdf,
					'canevas_id'=>$row->canevas_id,
					'report_date_start'=>$row->report_date_start,
					'report_date_end'=>$row->report_date_end,
			);
		}
		return $reportIncludeBlock;
	}

	/**@NAME: addReport
	 *@IN: $dbconnection l'objet de connexion PDO
	 *     $name string contenant le nom du report à add dans la BD
	 *     $date timestamp contenant la date de generation report à add dans la BD
	 *     $html string contenant le path html du report à add dans la BD
	 *     $pdf string contenant le path pdf du report à add dans la BD
	 *     $canevas_id integer contenant l'identifiant du canevas du report à add dans la BD
	 *     $date_start timestamp contenant la date start du report à add dans la BD
	 *     $date_end timestamp contenant la date end du report à add dans la BD
	 *@OUT: L'identifiant du report ajouté
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function addReport($dbconnection,$name,$date,$html,$pdf,$canevas_id,$date_start,$date_end)
	{
		$query= $dbconnection->prepare("INSERT INTO report (name,date_generate,path_html,path_pdf,canevas_id,report_date_start,report_date_end)
				    					VALUES(:name,NOW(),:html,:pdf,:canevas_id,to_date(:date_start, 'DD/MM/YYYY'),to_date(:date_end, 'DD/MM/YYYY')) RETURNING id");

		$query = Model_esia::executeStatement($query,array(':name' =>$name,
				':html'=>$html,
				':pdf'=>$pdf,
				':canevas_id'=>$canevas_id,
				':date_start'=>$date_start,
				':date_end'=>$date_end));
		$row=$query->fetch(PDO::FETCH_OBJ);
		return $row->id;
	}

	/**@NAME: delReport
	 *@IN: $dbconnection l'objet de connexion PDO
	 *     $id serial contenant l'identifiant de l'object report à delete dans la BD
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function delReport($dbconnection,$id)
	{
		if($id!=null)
		{
			$query= $dbconnection->prepare("DELETE FROM report WHERE id = :id");
			$query = Model_esia::executeStatement($query,array(':id' =>$id));
		}
	}

	/**@NAME: UpdtReport
	 *@IN: $dbconnection l'objet de connexion PDO
	 *     $id serial contenant l'identifiant du report  à update dans la BD
     *     $name (optionnelle) string contenant le nom du report à update dans la BD
     *     $date (optionnelle) date contenant la date du report à update dans la BD
     *     $html (optionnelle) string contenant le path html du report à update dans la BD
     *     $pdf (optionnelle) string contenant le path pdf du report à update dans la BD
     *     $canevas_id (optionnelle) integer contenant l'identifiant du canevas du report à update dans la BD
     *     $dateStart (optionnelle) date contenant le report_date_start du report à update dans la BD
     *     $dateEnd (optionnelle) date contenant le report_date_end du report à update dans la BD
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function UpdtReport($dbconnection,$id,$name=null,$date=null,$html=null,$pdf=null,$canevas_id=null,$dateStart=null,$dateEnd=null)
	{
		$query= $dbconnection->prepare("UPDATE report SET name=:name,date_generate=to_date(:date, 'DD/MM/YYYY'),path_html=:html,path_pdf=:pdf,canevas_id=:canevas_id,
				report_date_start=to_date(:start, 'DD/MM/YYYY'),report_date_end=to_date(:end, 'DD/MM/YYYY') WHERE id = :id;");

		$query = Model_esia::executeStatement($query,array(':id' =>$id,
				':name' =>$name,
				':date'=>$date,
				':html'=>$html,
				':pdf'=>$pdf,
				':canevas_id'=>$canevas_id,
				':start'=>$dateStart,
				':end'=>$dateEnd));
	}



	// TABLE report_send_users

	/**@NAME: getReportSendUsers
	 *@IN: $dbconnection l'objet de connexion PDO
	 *	   $idCan (optionnelle) précise l'id d'un send_canevas_id en particulier
	 * 	   $idUser (optionnelle) précise l'id d'un send_user_id  en particulier
	 *@OUT: Le report send users designe
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function getReportSendUsers($dbconnection,$idCan=null,$idUser=null)
	{
		$sql = "SELECT send_canevas_id,send_user_id,canevas_user_share,canevas_user_writing
		FROM report_send_users";

		$param=array();
		if(!empty($idCan)&& $idCan!=null)
		{
			$sql.=' WHERE send_canevas_id = ?';
			$param[]=$idCan;
			if(!empty($idUser)&& $idUser!=null)
			{
				$sql.=' AND send_user_id = ?';
				$param[]=$idUser;
			}
		}
		elseif(!empty($idUser)&& $idUser!=null)
		{
			$sql.=' WHERE send_user_id = ?';
			$param[]=$idUser;
		}

		$query = $dbconnection->prepare($sql);
		$query = parent::executeStatement($query,$param);

		$reportSendUsers=array();
		while($row=$query->fetch(PDO::FETCH_OBJ))
		{
			$reportSendUsers[]=array('send_canevas_id'=>$row->send_canevas_id,
					'send_user_id'=>$row->send_user_id,
					'canevas_user_share'=>$row->canevas_user_share,
					'canevas_user_writing'=>$row->canevas_user_writing,
			);
		}
		return $reportSendUsers;
	}

	/**@NAME: setReportSendUsers
	 *@IN: $dbconnection l'objet de connexion PDO
	 *     $idCan integer contenant l'identifiant du canevas
     *     $idUser integer contenant l'identifiant de l'utilisateur
     *     $proprietary bool true si créateur sinon false
     *     $writing bool true si pour droit d'ecriture
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function addReportSendUsers($dbconnection,$idCan,$idUser,$proprietary,$writing)
	{
		if($proprietary == true)
		{
			$query= $dbconnection->prepare("INSERT INTO report_send_users (send_canevas_id,send_user_id,canevas_user_share,canevas_user_writing)
					    					VALUES(:idCan,:idUser,:share,:share) RETURNING send_canevas_id");
			$query = Model_esia::executeStatement($query,array(':idCan' =>$idCan,
															   ':idUser'=>$idUser,
															   ':share'=>true));
		}
		else
		{
			if($writing==true)
			{
				$query= $dbconnection->prepare("INSERT INTO report_send_users (send_canevas_id,send_user_id,canevas_user_writing)
					    						VALUES(:idCan,:idUser,:share) RETURNING send_canevas_id");
				$query = Model_esia::executeStatement($query,array(':idCan' =>$idCan,
																   ':share'=>true,
																   ':idUser'=>$idUser));
			}
			else
			{
				$query= $dbconnection->prepare("INSERT INTO report_send_users (send_canevas_id,send_user_id)
					    					VALUES(:idCan,:idUser) RETURNING send_canevas_id");
				$query = Model_esia::executeStatement($query,array(':idCan' =>$idCan,
						':idUser'=>$idUser));
			}
		}

		$row=$query->fetch(PDO::FETCH_OBJ);
		return $row->send_canevas_id;
	}

	/**@NAME: delReportSendUsers
	 *@IN: $dbconnection l'objet de connexion PDO
	 *     $idCan integer contenant l'identifiant du canevas
     *     $idUser integer contenant l'identifiant de l'utilisateur
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function delReportSendUsers($dbconnection,$idCan,$idUser)
	{
		if($idCan!=null && $idUser!=null)
		{
			$query= $dbconnection->prepare("DELETE FROM report_send_users WHERE send_canevas_id = :idCan AND send_user_id = :idUser");
			$query = Model_esia::executeStatement($query,array(':idCan' =>$idCan,':idUser' =>$idUser));
		}
	}

	/**@NAME: delReportSendUsers
	 *@IN: $dbconnection l'objet de connexion PDO
	 *     $idCan integer contenant l'identifiant du canevas
	 *@EXCEPTION: 	EsiaDbException si une erreur survient
	 */
	public static function delReportSendUsers_Canevas($dbconnection,$idCan)
	{
		if($idCan!=null)
		{
			$query= $dbconnection->prepare("DELETE FROM report_send_users WHERE send_canevas_id = :idCan");
			$query = Model_esia::executeStatement($query,array(':idCan' =>$idCan));
		}
	}

	/**
	 * @brief récupère la liste des utilisateur qui ont le droit de lire/ecrire le Canevas
	 * @param PDO $dbconnection
	 * @param integer $id identifiant du Canevas
	 * @param boolean $writing true si on veut la liste des users qui ont aussi le droit d'ecriture
	 * @exception: esiaDBException
	 */
	public static function getUserReadWriteCanveas($dbconnection,$id,$writing=false)
	{
		if($writing==false)
		{
			$query = $dbconnection->prepare("SELECT send_user_id
  											FROM report_send_users
											WHERE canevas_user_share = false
											AND canevas_user_writing = false
											AND send_canevas_id = ?;");
		}
		else
		{
			$query = $dbconnection->prepare("SELECT send_user_id
  											FROM report_send_users
											WHERE canevas_user_share = false
											AND canevas_user_writing = true
											AND send_canevas_id = ?;");
		}

		$query = parent::executeStatement($query,array($id));
		$list=array();
		while($row=$query->fetch(PDO::FETCH_OBJ))
		{
			$list[]=$row->send_user_id;
		}
		return $list;
	}

	/**
	 * @brief met à jour un acces canevas
	 * @param PDO $dbconnection
	 * @param integer $id identifiant du canevas
	 * @param integer $user array identifiant des utilisateurs
	 * @exception: une esiaDBException
	 */
	public static function updateAccesCanevasView($dbconnection,$id,$users)
	{
		$query = $dbconnection->prepare("DELETE FROM report_send_users WHERE send_canevas_id = ? AND canevas_user_share = false and canevas_user_writing = false;");
		$query = parent::executeStatement($query,array($id));

		$query = $dbconnection->prepare("INSERT INTO report_send_users(send_user_id, send_canevas_id) VALUES (?,?);");
		foreach($users as $user)
		{
			$query = parent::executeStatement($query,array($user,$id));
		}
	}

	/**
	 * @brief met à jour un acces canevas
	 * @param PDO $dbconnection
	 * @param integer $id identifiant du canevas
	 * @param integer $user array identifiant des utilisateurs
	 * @exception: une esiaDBException
	 */
	public static function updateAccesCanevasWriting($dbconnection,$id,$users)
	{
		$query = $dbconnection->prepare("DELETE FROM report_send_users WHERE send_canevas_id = ? AND canevas_user_share = false;");
		$query = parent::executeStatement($query,array($id));

		$query = $dbconnection->prepare("INSERT INTO report_send_users(send_user_id, send_canevas_id,canevas_user_share,canevas_user_writing) VALUES (?,?,FALSE,TRUE);");
		foreach($users as $user)
		{
			$query = parent::executeStatement($query,array($user,$id));
		}
	}

	/**
	 * @brief met à jour un acces canevas
	 * @param PDO $dbconnection
	 * @param integer $id identifiant du canevas
	 * @exception: une esiaDBException
	 */
	public static function getOwnerCanevas($dbconnection,$idCanevas)
	{
		$query = $dbconnection->prepare("SELECT send_user_id FROM report_send_users WHERE send_canevas_id = ? AND canevas_user_share = true and canevas_user_writing = true;");
		$query = parent::executeStatement($query,array($idCanevas));
		while($row=$query->fetch(PDO::FETCH_OBJ))
		{
			$list[]=$row->send_user_id;
		}
		return $list;
	}

	/**
	 * @brief met à jour un acces canevas
	 * @param PDO $dbconnection
	 * @param integer $id identifiant du canevas
	 * @exception: une esiaDBException
	 */
	public static function updateAccesReport($dbconnection,$ListUser,$idcanevas,$idowner)
	{
		$query = $dbconnection->prepare("DELETE FROM report_send_users WHERE send_canevas_id = ? AND canevas_user_share = false AND canevas_user_writing = false ");
		$query = parent::executeStatement($query,array($idcanevas));
		$query = $dbconnection->prepare("INSERT INTO report_send_users(send_user_id, send_canevas_id) VALUES (?,?);");
		foreach($ListUser as $user)
		{
			if($user!=$idowner)
			{
				$query = parent::executeStatement($query,array($user,$idcanevas));
			}
		}
	}


}
?>
