<?php
/*DESCRIPTION: inclus les variables habituelles pour la gestion d'un block et vérifie les droits d'accès
 *APRES l'inclusion du common_block les variables suivantes sont créées:
 *PHP:
 *      $dbconnection objet PDO de connexion à la DB
 *      $webplugin_path chemin d'accès au web plugin de repport (default: /usr/local/esia/public_html/plugin/report/
 *      $lang tableau associatif avec les variables de langue
 *      $action l'action passé dans l'url ou 'view'
 *      $gendate tableau associatif reprenant les paramètres global avec les clés suivantes:
 *               ['start']  timestamps de début
 *               ['end']    timestamps de fin  
 *               ['interval'] interval en nombre de jour au format php. voir %a par rapport à la date de début  https://www.php.net/manual/fr/dateinterval.format.php
 *      $block les données du block en DB
 *      $parameters un tableau associatif reprenant les paramètres du block
 * SMARTY
 *      $block les informations du block
 *      $parameter les parametres du block (JSON)
 *      $action l'action passé dans l'url ou 'view'
 */
$action='view';
$is_cli=false;
$id_block = NULL;
$gendate['start'] = NULL;
$gendate['end'] = NULL;
$gendate['interval'] = NULL;
$smarty = NULL;
$lang = NULL;
$webplugin_path=NULL;
$dbconnection= NULL;
//si le serveur root est vide c'est qu'on est en mode CLI
if(empty($_SERVER['DOCUMENT_ROOT']))
{
	$is_cli=true;
	$_SERVER['DOCUMENT_ROOT']='/usr/local/esia/public_html/';
    //gestion des paramètres:
    $SHORT_OPTS="a:i:s:e:l:";
    $LONG_OPTS=array("action:","id:","start:","end:","language:");
	$options = getopt($SHORT_OPTS, $LONG_OPTS);
	$action	  = getParam($options,"action","a");
	$id_block = getParam($options,"id","i");
	$start	  = getParam($options,"start","s");
	$end	  = getParam($options,"end","e");
	$language = getParam($options,"language","l",'fr');

    //gestion de la date
    $gendate['start'] = array('date' => $start);
    $gendate['end'] = array('date' => $end);
	$datetime1 = new DateTime($start);
	$datetime2 = new DateTime($end);
	$gendate['start']['timestamp'] = $datetime1->getTimestamp();
	$gendate['end']['timestamp'] = $datetime2->getTimestamp();
	$today = new DateTime(date("Y-m-d"));
	$diff = $datetime1->diff($datetime2);
	$interval = $diff->format('%a');
    $gendate['interval'] = "-".$interval."d";

	$diff = $datetime2->diff($today);
    // Si date fin du rapport est plus grande ou equale à la date du jour
	if($diff->format('%a')=="0")
	{
        $gendate['end']['interval']="N";
	}
	else // Si choix de date manuel
	{
		$dateFin = $diff->format('%a');
		$interval = $dateFin + $interval;
        $gendate['end']['interval'] = "-".$dateFin."d";
	}
}
else
{

    $ESIA_WIDGET_NOTREE=true;
    include_once $_SERVER['DOCUMENT_ROOT'].'/common.php';
}
$path = rtrim ($_SERVER['DOCUMENT_ROOT'],'/');
//inclusion des librairie
include_once $path.'/esia.conf.php';
include_once $path.'/Model_esia.php';
include_once $path.'/Model_adm.php';
include_once $path.'/libs/convert.lib.php';
//on est en CLI, on charge les variables de langue + smarty
$apache_plugin_path= NULL;
if($is_cli===TRUE)
{
	try
	{
		$dbconnection = new PDO('pgsql:host='.DB_HOST.';port='.DB_PORT.';dbname='.DB_NAME, DB_USERNAME, DB_PWD);
		$dbconnection->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_WARNING);
	}
	catch(Exception $e)
	{
		echo 'PDO SQL ERROR: '.$e->getMessage().'<br />';
		echo 'N° : '.$e->getCode();
	}  
    //Chargement du PATH 
    $arr = Model_esia::getWebPlugin($dbconnection,false,'WEBP_REPORT');
    $apache_plugin_path = $arr[0]['apache_path'];
    $webplugin_path = $path.$apache_plugin_path;
    //Variable de langue
 	include $webplugin_path.'/lang/'.$language.'.php';
	include $path.'/lang/'.$language.'/common_plugin_name.php';
    //Chargement SMARTY
    require_once(SMARTY_DIR . 'Smarty.class.php');
	$theme = Model_esia::getApplicationTheme($dbconnection);
    $smarty = new Smarty();
	$smarty->template_dir = $path.'/theme/'.$theme.'/template/';
	$smarty->compile_dir = $path.'/theme/'.$theme.'/templates_c/';
	$smarty->config_dir = $path.'/configs/';
	$smarty->cache_dir = $path.'/cache/';
    $smarty->assign('css', '/theme/'.$theme.'/design.css');
	$smarty->assign('title','Esia Network Management');
	$smarty->assign('lang', $lang);
	//chemin d'accès au repertoire du plugin contenant les templates
	include_once $webplugin_path.'/Model_Report.php';
}
else
{
    $arr = Model_esia::getWebPlugin($dbconnection,false,'WEBP_REPORT');
    $apache_plugin_path = $arr[0]['apache_path'];
    $webplugin_path = $path.$apache_plugin_path;
    //chemin d'accès au repertoire du plugin contenant les templates
    include_once $webplugin_path.'/Model_Report.php';
    include_once $webplugin_path.'/libs/report.lib.php';
    session_write_close();
    
}
$smarty->assign('path_webplugin', $apache_plugin_path);
if(!empty($_POST['blockid'])) // Lors de la modification du bloc
{
	$id_block= $_POST['blockid'];
}
elseif(!empty($_GET['id'])) // Lors de l'ajout du bloc
{
	$id_block=$_GET['id'];
}
//si on a lancé autre chose qu'une action de vue
if(!empty($_GET['action']))
{
	$action=$_GET['action'];
	if($action != 'generate')
	{
		$access = Model_Report::getReportSendUsers($dbconnection,$id_block,$user->getId());
		$access=$access[0];
		if($access['canevas_user_writing']==true)
		{
			$smarty->display('no_access.html');
			exit(0);
		}
	}
}
$block = NULL;
$parameters = NULL;
try
{
    $query=Model_Report::getReportIncludeBlock($dbconnection,$id_block);
    $block= $query[0];
    $smarty->assign('block', $block);
    $smarty->assign('parameters', $block['parameters']);
    $smarty->assign('action', $action);
    $parameters =  $block['parameters'];
}
catch(Exception $e)
{
    echo 'PDO SQL ERROR: '.$e->getMessage().'<br />';
    echo 'N° : '.$e->getCode();    
}
/**
 @brief retourne la valeur associé à la clé
 @detail retourne la valeur associé au paramètre. ou une valeur par défaut
 @params array $options le tableau de paramètre global
 @params string $name1 le nom court du paramètre (ex: -H 127.0.0.1)
 @params string $name2 le nom long du paramètre (ex: --host 127.0.0.1)
 @params string $default (optionnel) la valeur par défaut du paramètre s'il n'est pas spécifié
 @retval	null|mixed la valeur du paramètre
 @throw void
 */
function getParam($options,$name1,$name2,$default=null)
{
	if( isset( $options[$name1] ) ) return $options[$name1];
	if( isset( $options[$name2] ) ) return $options[$name2];
	return $default;
}
/*@NAME: convert_tree_to_select
 *@IN: $top un tableau associatif de type renvoyer par Model_esia::getGroupDeviceIn($dbconnection)
 *	$parent_id id du groupe du groupe parent
 *@OUT: un tableau contenant les noms des groupes de device enfants
 *array('id'=>$row->device_group_id,
 *		'name'=> $row->device_group_name,
 'level'=> niveau dans le tableau
 'id du parent'=> niveau dans le tableau
 *@TREAT: FONCTION RECURSIVE !!!!! (utilisée avec la fonction getGroupDeviceIn)
 *		transforme un tableau de tableau récursif de  getGroupDeviceIn en tableau simple avec une valeur 'level' indiquant le niveau du auquelle ils se trouvent
 *@EXCEPTION: /
 */

function convert_tree_to_select($top,$itt,$parentid=null,$parentname=null)
{
	/*for($i=0;$i<$itt;$i++)
	 echo'=';
	 echo $top['name'].'<br />';*/
	$pname=null;
	if(isset($parentname))
	{
		$pname = $parentname.' > '.$top['name'];
	}
	else
	{
		$pname = $top['name'];
	}
	$arr=array();
	$arr[]=array('id'=>$top['id'],'name'=>$top['name'],'level'=>$itt,'parent'=>$parentid,'parent_name'=>$pname);
	$itt++;
	if(isset($top['child']))
	{
		$tmp=array();
		foreach($top['child'] as $child)
		{
			$tmp = convert_tree_to_select($child,$itt,$top['id'],$pname);
			$arr = array_merge($arr, $tmp);
		}
	}
	
	return $arr;
}
