<?php
use function Convert\bytes;

/*DESCRIPTION: inclus les variables habituelles pour la gestion d'un block et vérifie les droits d'accès
 *APRES l'inclusion du common_block les variables suivantes sont créées:
 *PHP:
 *      $dbconnection objet PDO de connexion à la DB
 *      $webplugin_path chemin d'accès au web plugin de repport (default: /usr/local/esia/public_html/plugin/report/
 *      $lang tableau associatif avec les variables de langue
 *      $action l'action passé dans l'url ou 'view'
 *      $gendate tableau associatif reprenant les paramètres global avec les clés suivantes:
 *               ['start']  timestamps de début
 *               ['end']    timestamps de fin
 *               ['interval'] interval en nombre de jour au format php. voir %a par rapport à la date de début  https://www.php.net/manual/fr/dateinterval.format.php
 *      $block les données du block en DB
 *      $parameters un tableau associatif reprenant les paramètres du block
 * SMARTY
 *      $block les informations du block
 *      $parameter les parametres du block (JSON)
 *      $action l'action passé dans l'url ou 'view'
 */
require_once '/usr/local/esia/public_html/plugin/report/report.conf.php';
require_once REPORT_COMMON_BLOCK;
$params = $block['parameters'];

//UPDATE interface web
if($action=="generate")
{
    if( $interval == 1 ) {//One day only
        $date = new DateTime();
        $date->setTime(0,0,0);
        $end_date_ts = $date->getTimestamp();
        $end_date_ts--;
    }
    $nodes = array();
    if($params['element_type']=='group_node')
    {
        $nodes = Model_esia::getAllNodeofGroup($dbconnection, null, $params['element_dbid']);
    }
    else
    {
        foreach ($params['element_dbid'] as $nodeid)
        {
            try
            {
                $infonode=Model_esia::InstanceNode($dbconnection,$nodeid);
                $nodes[]=$infonode;
            }
            catch(Exception $e)
            {

            }
        }
    }
    $list = array();
    foreach($nodes as &$node)
    {
        $services = Model_esia::getServices($dbconnection, $node->getId());
        foreach($services as &$service)
        {
            if(preg_match('#STORAGE#',$service['check_plugin_name']))
            {
                if($service['real_state'] == 3 )
                {
                    $service['value']['hdd']=null;
                }
              //  echo '<pre>';
              //  print_r($service);
                $common_name = Model_esia::getCommonName($lang,$service['name'],$service['check_plugin_name']);
                $common_name = preg_replace('#^.*\-#','', $common_name);
                $name = $node->getName().'-'.$service['name'];
                $descr = htmlentities($node->getDescription() , ENT_QUOTES);
                $list[$name]=array('nodeid'=>$node->getId(),
                    'name'=>$node->getName().' - '.trim($common_name),
                    'group'=> $node->getGroup(),
                	'description'=>$descr,
                    'ip'=>$node->getIPAddress(),
                    'serviceid'=>$service['id'],
                    'percent_used'=>(int)$service['value']['hdd'],
                    'percent_free'=>(100-$service['value']['hdd']));
            }
        }
    }
    ksort($list);
    if(empty($params['form']))
    {
        $params['form']='tab2';
    }
    //Affichage
    echo '<div class="clear"></div>';
    //echo'<section class="blockTier">
    echo '<section class="blockView" style="page-break-inside:avoid;">
       		<div class="blockView_title">
	       		<h3 style="text-align:'.$params['title']['style']['text-align'].';
						font-size:'.$params['title']['style']['font-size'].';
						color:'.$params['title']['style']['color'].'"
						><p>'.$params['title']['text'].'</p></h3>
        	</div>
	       	<div class="pad">
        		<p style="text-align:'.$params['description']['style']['text-align'].';
						font-size:'.$params['description']['style']['font-size'].'"
							>'.$params['description']['text'].'</p></div>';
    if($params['form']=='tab2')
    {
       echo '<table class="tab"><thead>';
       if($params['table']['columnshow']['group'] !='none')
       {
            echo '<th>'.$lang['REPORT_DEVICE_GROUP_NAME'].'</th>';
       }
       echo '<th>'.$lang['REPORT_DEVICE_NAME'].'</th>';
       if($params['table']['columnshow']['ip'] !='none')
       {
           echo '<th>'.$lang['REPORT_ADD_IP'].'</th>';
       }
       if($params['table']['columnshow']['description'] !='none')
       {
           echo '<th>'.$lang['REPORT_BLOCK_DESCRIPTION'].'</th>';
       }
       echo '<th>'.$lang['REPORT_AVAILABILITY_DISPO'].'</th>';
       echo '</thead><tbody>';
       foreach ($list as $line)
       {
           echo '<tr>';
           if($params['table']['columnshow']['group'] !='none')
           {
               echo '<td>'.$line['group'].'</td>';
           }

           echo '<td>'.$line['name'].'</td>';
           if($params['table']['columnshow']['ip'] !='none')
           {
               echo '<td>'.$line['ip'].'</td>';
           }
           if($params['table']['columnshow']['description'] !='none')
           {
               echo '<td>'.$line['description'].'</td>';
           }
           echo '<td>';
           if(empty($line['percent_used']))
           {
               echo '<p class="EventUnknown_Incident">No data</p>';
           }
           else
           {
               if($line['percent_used']>$params['criticalThreshold'])
               {
                   echo '<p class="EventCritical_Incident">';
               }
               elseif($line['percent_used']>$params['warningThreshold'])
               {
                   echo '<p class="EventWarning_Incident">';
               }
               else
               {
                   echo '<p class="EventOK_Incident">';
               }
               echo $line['percent_used'].'%</p>';
           }
           echo'</td>';
           echo '</tr>';
       }
       echo'</tbody></table>';
    }
    elseif($params['form']=='donut' || $params['form']=='pie' || $params['form']=='gauge' )
    {
        foreach ($list as $line)
        {
            echo '<div style="float:left; width:250px; text-align: center; height:180px;">'.$line['name'];
            if(!empty($line['percent_used']))
            {
                echo '<div id="donut_chart'.$idInclude.'_'.$line['serviceid'].'" style="margin:auto"></div>
                    <script type="text/javascript">
                    $(document).ready(function(){ ';
                if($params['form']=='donut')
                {
                   echo "var arr=Array(['OK',".$line['percent_free']."],['warning',".$line['percent_used']."],['critical',0],['unknwon',0]);
                    Utils.generateDonutsStatic(arr,\"donut_chart".$idInclude.'_'.$line['serviceid']."\",false,100,150);";
                }
                elseif($params['form']=='pie')
                {
                    echo "var chart = c3.generate({
                                                	    bindto: '#donut_chart".$idInclude.'_'.$line['serviceid']."',
                                                	    data: {
                                                    		columns: [['OK',".$line['percent_free']."],['warning',".$line['percent_used']."],['critical',0],['unknwon',0]],
                                                			type:'pie',
                                                		},
                                                		legend: {
                                                			show: false
                                                		},
                                                		color: {
                                                			  pattern: ['#83bc00', '#ffcb1f', '#da002e', '#575759', '#3263c5']
                                                			},
                                                		size: {
                                                		  height: 150
                                                		}
                                                	});";

                }
                else
                {
                    echo "var arr=Array('".$line['name']."',".$line['percent_used'].");";
                    echo "Utils.generateGaugeThreshold(arr,\"donut_chart".$idInclude.'_'.$line['serviceid']."\",null,Array(".$params['warningThreshold'].",".$params['criticalThreshold']."),100);";
                }
                echo '}); </script>';
            }
            else
            {
                echo '<br /><br /><br /><br />No DATA';
            }
            echo'</div>';

        }
        echo '<div class="clear">';
        if($params['form']=='donut' || $params['form']=='pie')
        {
            echo'</div><table style="margin:auto">
                    <tr><td class="eventOK" style="height:15;width:15px;background-color:#83bc00;"></td><td style="padding-left:10px">'.$lang['REPORT_DISK_FREE_SPACE'].'</td>
                        <td style="width:20px"></td>
                        <td style="height:15;width:15px; background-color:#ffcb1f;"></td><td style="padding-left:10px">'.$lang['REPORT_STOCKAGE_USED'].'</td>
                </table><div class="clear"></div>';
        }
    }
    //génération en graphique chart
    elseif($params['form']=='graphCol')
    {
        $c3data=array("data1");
        $c3headder=array();
        foreach($list as $line)
        {
            $c3data[]=$line['percent_used'];
            $c3headder[]=$line['name'];
        }
        $c3data = json_encode($c3data);
        $c3headder = json_encode($c3headder);
        echo '<div id="bar_chart'.$idInclude.'" style="min-width:700px;"></div>
                <script type="text/javascript">
                    $(document).ready(function(){
                    var chart = c3.generate({
						bindto: "#bar_chart'.$idInclude.'",
					    data: {
                            columns: ['.$c3data.'],
					        type: "bar",
                            labels: {
                                        format: function(value, ratio, id)
                                            {
                                                if(!value) {   return "No Data";}
                                                else if(value===0) return \'00%\';
                                                else return value+\'%\';
                                            }
                                    },
                            empty: { label: { text: "No Data Available" }   },
						    color: function(color,d)
    						    	{
    						    		if(!d.value)
    						    		{
    						    			return	\'#575759\';
    						    		}
    						    		else if(d.value > '.$params['criticalThreshold'].')
    						    		{
    						    			return \'#da002e\';
    						    		}
    						    		else if(d.value > '.$params['warningThreshold'].')
    						    		{
    						    			return	\'#ffcb1f\';
    						    		}
    						    		else
    						    		{
    						    			return	\'#83bc00\';
    						    		}
    						        }
					    },
					    bar: {
					        width: { ratio: 0.5 }
					    },
					    axis: {
					        rotated: true,
						    x:{
		                        type: \'category\',
                                tick: { multiline: false},
		                        categories: '.$c3headder.'
		                    },
		                    y:{
		                    	min: 0,
		                    	max: 100,
		                    	padding: 0
		                    }
					    },
					    legend: { show: false }
					});});</script>';
    }
    echo '</section>';
}
elseif($action=="node")
{
    $nodes = Model_esia::getNodeList($dbconnection,$user->getId(),null,Model_esia::NODE_INSTANCE);
    $list=array();

    foreach($nodes as $node)
    {
        $arr = array('id'=>$node->getId(),'parent_name'=>$node->getGroup().'>'.$node->getName());
        if($params['element_type']=='node')
        {
            if(in_array($node->getId(),$params['element_dbid']))
            {
                $arr['selected']=1;
            }
        }
        $list[]= $arr;
    }
    echo json_encode($list);
}
elseif($action=="group_node")
{
    $arr = Model_esia::getGroupDeviceIn($dbconnection);
    $list =array();
    foreach($arr as $top)
    {
        $tmp = convert_tree_to_select($top,0);
        $list = array_merge($list, $tmp);
    }
    if($params['element_type']=='group_node')
    {
        foreach($list as &$elem)
        {
            if(in_array($elem['id'], $params['element_dbid']))
            {
                $elem['selected']=1;
            }
        }
    }
    echo json_encode($list);

}
elseif($action=="update")
{
    $template_path = $path.'/plugin/report/templates/';
    $smarty->assign('blockid',$block['id']);
    $smarty->assign('canevas_id',$block['include_canevas_id']);
    if(isset($_POST['blockid'])&&!empty($_POST['blockid']))
    {
        //Title
        $params['title']['text']=$_POST["block_name"];
        $size = $_POST["name_size"];
        $params['title']['style']['font-size']=$size."px";
        $params['title']['style']['text-align']=$_POST["name_position"];
        $params['title']['style']['color']=$_POST["block_color"];

        //Descr
        $params['description']['text']=$_POST["block_description"];
        $size=$_POST["block_size"];
        $params['description']['style']['font-size']=$size."px";
        $params['description']['style']['text-align']=$_POST["description_position"];

        //
        // Forme
        $params['form']=$_POST['form'];
        // Seuil de Warning et Critical
        $params['criticalThreshold']=$_POST['criticalThreshold'];
        $params['warningThreshold']=$_POST['warningThreshold'];

        //Paramètre du tableau
        if( empty($_POST['tab_col_group']) )	$_POST['tab_col_group'] = 'none';
        if( empty($_POST['tab_col_ip']) )	$_POST['tab_col_ip'] = 'none';
        if( empty($_POST['tab_col_descr']) )	$_POST['tab_col_descr'] = 'none';
        $params['table']['columnshow']['group']=$_POST['tab_col_group'];
        $params['table']['columnshow']['ip']=$_POST['tab_col_ip'];
        $params['table']['columnshow']['description']=$_POST['tab_col_descr'];
        //Type d'affichage
        $params['element_type']=$_POST['select_type_link'];
        $params['element_dbid']=$_POST['elementselect'];

        $paramSave = json_encode($params);

        Model_Report::UpdtReportIncludeBlock($dbconnection,$_POST['blockid'],$block['include_block_id'],$block['include_canevas_id'],$block['include_position'],$paramSave);
        $smarty->assign('l_success',$lang['UPDATE_REPORT_SUCCESS']);
    }
    //explode pour le formulaire afin de spécifier la taille dans un input type numéric
    $taille = explode("px", $params['title']['style']['font-size']);
    $smarty->assign('title_police_size',$taille[0]);
    $taille = explode("px", $params['description']['style']['font-size']);
    $smarty->assign('description_police_size',$taille[0]);
    $smarty->assign('description_align',$params['description']['style']['text-align']);
    $smarty->assign('title_align',$params['title']['style']['text-align']);
    $smarty->assign('params',$params);
    $smarty->assign('action','update');
    //on liste les différents groupes de noeud
    $arr = Model_esia::getGroupDeviceIn($dbconnection);
    $select =array();
    foreach($arr as $top)
    {
        $tmp = convert_tree_to_select($top,0);
        $select = array_merge($select, $tmp);
    }
    $smarty->assign('adm_nodegroup', $select);

    $smarty->display($template_path.'storage.html');
}
?>
