<?php
use function Convert\bytes;

/*DESCRIPTION: inclus les variables habituelles pour la gestion d'un block et vérifie les droits d'accès
 *APRES l'inclusion du common_block les variables suivantes sont créées:
 *PHP:
 *      $dbconnection objet PDO de connexion à la DB
 *      $webplugin_path chemin d'accès au web plugin de repport (default: /usr/local/esia/public_html/plugin/report/
 *      $lang tableau associatif avec les variables de langue
 *      $action l'action passé dans l'url ou 'view'
 *      $gendate tableau associatif reprenant les paramètres global avec les clés suivantes:
 *               ['start']  timestamps de début
 *               ['end']    timestamps de fin
 *               ['interval'] interval en nombre de jour au format php. voir %a par rapport à la date de début  https://www.php.net/manual/fr/dateinterval.format.php
 *      $block les données du block en DB
 *      $parameters un tableau associatif reprenant les paramètres du block
 * SMARTY
 *      $block les informations du block
 *      $parameter les parametres du block (JSON)
 *      $action l'action passé dans l'url ou 'view'
 */
require_once '/usr/local/esia/public_html/plugin/report/report.conf.php';
require_once REPORT_COMMON_BLOCK;

if($action=="generate")
{
//	$param = json_decode($query['include_parameter'],true);

    $userid=null;
    if(@is_null($user)==false)
    {
        $userid = $user->getId();
    }
    else
    {
        $report_user = Model_Report::getOwnerCanevas($dbconnection,$block['include_canevas_id']);
        $userid = $report_user[0];
    }
    $parameters = $block['parameters'];
    //pour les anciens blocs qui n'ont pas la variable
    if(!isset($parameters['nodeError']))
    {
    	$parameters['nodeError']=true;
    }
    $arr_id_node = array();
    //on créer un tableau de noeud
    if($parameters['type']=="groupenoeud")
    {
        $tab_group_node = Model_esia::getAllNodeofGroup($dbconnection,$userid,$parameters['groupnodeid']);
        foreach ($tab_group_node as $node)
        {
            $arr_id_node[] = array('id' => $node->getId(),
            						'name'=> $node->getName(),
            						'ip'=> $node->getIPAddress(),
					            	'description'=> $node->getDescription(),
            						'group'=> $node->getGroup()
            						);
        }
    }
    else
    {
    	foreach ($parameters['nodeid'] as $id)
    	{
    		$node = Model_esia::InstanceNode($dbconnection,$id);
    		$arr_id_node[] = array('id' => $node->getId(),
    			'name'=> $node->getName(),
    			'ip'=> $node->getIPAddress(),
    			'description'=> $node->getDescription(),
    			'group'=> $node->getGroup()
    		);
    	}
    }
    $listnode_available = array();
    $listnode_nodata = array();
    $listnode_error = array();
	foreach ($arr_id_node as $node)
	{
		$elementTab = array();
		$elementTab['device_name']=$node['name'];
		$elementTab['device_ip_addr']=$node['ip'];
		$elementTab['device_description']=$node['description'];
		$elementTab['device_group_name']=$node['group'];
		$elementTab['device_vCPU']="No Data";
		$elementTab['device_ram']="No Data";
		$elementTab['device_usage_ram']=0;
		$elementTab['device_stockage_installe']="No Data";
		$query = Model_Report::getUsageRessourceNode($dbconnection,$node['id']);
		if(!empty($query)&& $query!=null)
		{
			$partnum=1;
			$stockage_total = 0;
			foreach ($query as $elem)
			{
				if((preg_match("/LOAD/",$elem['plugin_name']) || preg_match("/CPU/",$elem['plugin_name']))  && $parameters['affiche_cpu']==true)
				{
					if(preg_match("/(\d+)\s+CPU/",$elem['service_last_stdout'],$matches)) // 1 CPU, load 11.0% < 80% : OK
					{
						$elementTab['device_vCPU']=$matches[1];
					}
					$elementTab['device_cpu_usage'] = average_service($dbconnection,$elem['service_id'], $gendate['interval'],$gendate['end']['timestamp'],$rrdpath)['cpu'];
				}
				elseif(preg_match("/STORAGE/",$elem['plugin_name']) && $parameters['affiche_stockage']==true)
				{
					$hdd = average_service($dbconnection,$elem['service_id'], $gendate['interval'],$gendate['end']['timestamp'],$rrdpath);
					if(!empty($hdd)) //  /: 19%used(1399MB/7321MB) (<80%) : OK  // C:\ Label:TI31213800A Serial Number 76190076: 9%used(32160MB/371265MB) (<80%) : OK
					{
						$name= preg_replace('#'.$elem['plugin_name'].'#','',$elem['service_name']);
						if(empty($name))
						{
							//on va chercher le nom dans les paramètres du service (ancien et nouveau format: -n ou -m)
							if(preg_match("#\-[nm]\s+([\"\^0-9a-zA-Z\*\.\:\\\/]*)#",$elem['service_parameter'],$regs))
							{
								$name = $regs[1];
								$name = ltrim($name,'"');
								$name = ltrim($name,'^');
							}
							//dans la sortie du service suivant le nouveau format (galère)
							elseif(preg_match("/\:\s+(\S+):/",$elem['service_last_stdout'],$regs))
							{
								$name = $regs[1];
								$name = ltrim($name,'^');
							}
							else
							{
								$name = $partnum;
								$partnum++;
							}
						}
						else
						{
							$name = ltrim($name,'_');
						}
						$stockage_total = $stockage_total+$hdd['total'];
						$hdd = average_service($dbconnection,$elem['service_id'], $gendate['interval'],$gendate['end']['timestamp'],$rrdpath);
						
						$free = Convert\bytes($hdd['total']-$hdd['used']);
						$size = Convert\bytes($hdd['total']);
						$elementTab['device_storage'][] = array('name'=> $name,'used'=> $hdd,'size'=>$size,'free'=>$free);
					}
				}
				elseif((preg_match("/MEM/",$elem['plugin_name']) || preg_match("/RAM/",$elem['plugin_name'])) && $parameters['affiche_ram']==true)
				{

					$ram =  average_service($dbconnection,$elem['service_id'], $gendate['interval'],$gendate['end']['timestamp'],$rrdpath);
					if(!empty($ram))
					{
						if(!empty($ram['ram']))
						{
							$elementTab['device_ram']=Convert\bytes($ram['total']);
							$elementTab['device_usage_ram']=$ram['ram'];
						}
					}
				}
			}
			if($stockage_total==0)
			{
				$elementTab['device_total_storage']="No Data";
			}
			else
			{
				$elementTab['device_total_storage']= Convert\bytes($stockage_total);
			}
			if($parameters['affiche_stockage']== true)
			{
				$count = count($elementTab['device_storage']);
				if($count ==0)
				{
					$count=1;
				}
				$elementTab['number_storage']=$count;
			}
			else
			{
				$elementTab['number_storage']=1;
			}
			if($elementTab['device_vCPU']=="No Data" 
					&& $elementTab['device_ram']=="No Data"  
					&& $elementTab['device_usage_ram']=="No Data"
					&& $elementTab['device_stockage_installe']=="No Data")
			{
				$listnode_nodata[]=$elementTab;
			}
			else
			{
            	$listnode[]=$elementTab;
			}
		}
		else
		{
			$listnode_nodata[]=$elementTab;
		}
	}
	$smarty->assign('parameters',$parameters);	
	$smarty->assign('listnodeerror',$listnode_nodata);	
	$smarty->assign('listnode',$listnode);	
}
elseif($action=="update")
{
    //Code permettant l'administration du bloc
    $parameters = $block['parameters'];	
	if(isset($_POST['blockid'])&&!empty($_POST['blockid']))
	{
		try
		{
            //traite les données post pour le style du titre et de la description
            $block = getPostDefaultParams($block,$_POST);
            $parameters = $block['parameters'];
            //traitement des variable POST
			
			// Service & Noeud
			if ($parameters['type']=='noeud')
			{
				$parameters['nodeid']=$_POST['nodes'];
			}
			else
			{
				$parameters['groupnodeid']=$_POST['groupnodes'];;
			}
			$parameters['affiche_groupNoeud']=$_POST['groupNoeud'];
			$parameters['affiche_espaceLibre']=$_POST['espacelibre'];
			// Seuil de Warning et Critical
			$parameters['SeuilWarningCpu']=$_POST['SeuilWarningCpu'];
			$parameters['SeuilCriticalCpu']=$_POST['SeuilCriticalCpu'];

			$parameters['SeuilWarningRam']=$_POST['SeuilWarningRam'];
			$parameters['SeuilCriticalRam']=$_POST['SeuilCriticalRam'];

			$parameters['SeuilWarningStorage']=$_POST['SeuilWarningStorage'];
			$parameters['SeuilCriticalStorage']=$_POST['SeuilCriticalStorage'];

			// Affichage colonne
			$parameters['affiche_ip']=$_POST['add_ip'];
			$parameters['affiche_cpu']=$_POST['cpu'];
			$parameters['affiche_description']=$_POST['descript'];
			$parameters['affiche_ram']=$_POST['ram'];
			$parameters['affiche_stockage']=$_POST['stockage'];
			if(isset($_POST['nodeError']))
			{
				$parameters['nodeError']=$_POST['nodeError'];
			}
			else
			{
				$parameters['nodeError']='none';
			}
            $paramSave = json_encode($parameters);
			Model_Report::UpdtReportIncludeBlock($dbconnection,$block['id'],$block['include_block_id'],$block['include_canevas_id'],$block['include_position'],$paramSave);
                        //la variable l_success est affichée en rouge dans le smarty
			$smarty->assign('l_success',$lang['UPDATE_DASHBOARD_SUCCESS']);
		}
		catch (EsiaDbException $e)
		{
			$smarty->assign('l_error',$e->getMessage());
		}
		catch (Exception $e)
		{
			$smarty->assign('l_error',$e->getMessage());
		}
	}
    $title = $parameters['title']['style'];
	$description = $parameters['description']['style'];
	$title = getBlockStyle($title,14,'left','#575759');
	$description = getBlockStyle($description,12,'left','#575759');
	$smarty->assign('titlestyle',$title);
	$smarty->assign('descriptionstyle',$description);
	//active par défaut l'affichage des noeuds en erreurs
	if(!isset($parameters['nodeError']))
	{
		$parameters['nodeError']=true;
	}
    //récupération des données pour l'affichage
    //on fixe le mode update
	$listnode = array();
    $list_group_node = array();
	//Récupération des services
    if($parameters['type']=="noeud")
	{
		//Récupération des noeuds
		$nodes = Model_esia::getNodeList($dbconnection,$user->getId(),null,Model_esia::NODE_INSTANCE);
		$list=array();
		foreach($nodes as $node)
		{
			$selected='no';
			if(in_array($node->getId(),$parameters['nodeid']))
			{
				$selected='yes';
			}
			$list[]=array('id'=>$node->getId(),
					'name'=>$node->getGroup().'>'.$node->getName(),
					'selected'=>$selected

			);
		}
	}
	else
	{
		$list = Model_esia::getNodeGroupHierarchyByUser($dbconnection,$user->getId());
		$list_group_node=array();
		foreach($list as $node)
		{
			$selected='no';
			if(in_array($node['id'],$parameters['groupnodeid']))
			{
				$selected='yes';
			}

			$list_group_node[]=array('id'=>$node['id'],
					'name'=>$node['name'],
					'selected'=>$selected);
		}
	}
	$smarty->assign('param',$parameters);
	$smarty->assign('adm_list_node', $list);
	$smarty->assign('adm_list_group_node', $list_group_node);
	$smarty->assign('action','update');
}
elseif($action =="getservice")
{
	$template_path = $path.'/plugin/report/blocks/templates';
	if(isset($_GET['nodeid']))
	{
		$tablenodeid = json_decode($_GET['nodeid']);
		$list=array();
		foreach($tablenodeid as $nodeid)
		{
			$node = Model_esia::InstanceNode($dbconnection, $nodeid);
			if($user->getAccess($dbconnection, "device_view",$node->getName())==1)
			{
				$services = Model_esia::getServices($dbconnection,$node->getId());
				foreach ($services as $service)
				{
					$common_name = Model_esia::getCommonName($lang, $service['name'],$service['check_plugin_name']);
					$list[$service['id']]=$node->getName().' > '.$common_name;
				}
			}
		}
		echo json_encode($list);
		exit(0);
	}
}
//chemin d'accès au template de votre block
$smarty->display($webplugin_path.'/blocks/templates/useResources.html');
function createelementTab($value,$param)
{
	echo '<tr>';
	if($param['affiche_groupNoeud']==true)
	{
		echo'<td><p style="word-wrap:break-word">'.$value['device_group_name'].'</p></td>';
	}
	echo'<td><p style="word-wrap:break-word">'.$value['device_name'].'</p></td>';
	if($param['affiche_ip']==true)
	{
		echo'<td><p style="word-wrap:break-word">'.$value['device_ip_addr'].'</p></td>';
	}
	if($param['affiche_description']==true)
	{
		echo'<td><p style="word-wrap:break-word">'.$value['device_description'].'</p></td>';
	}
	if($param['affiche_cpu']==true)
	{
		echo'<td><p style="word-wrap:break-word">'.$value['device_vCPU'].'</p></td>'; // vCPU
		if($param['SeuilCriticalCpu']<=$value['device_cpu_usage'])
		{
			echo'<td><p class="EventCritical_Incident" style="word-wrap:break-word">'.$value['device_cpu_usage'].'%</p></td>'; // CPU usage
		}
		elseif($param['SeuilWarningCpu']<=$value['device_cpu_usage'])
		{
			echo'<td><p class="EventWarning_Incident" style="word-wrap:break-word">'.$value['device_cpu_usage'].'%</p></td>'; // CPU usage
		}
		else
		{
			echo'<td><p style="word-wrap:break-word">'.$value['device_cpu_usage'].'%</p></td>'; // CPU usage
		}
	}
	if($param['affiche_ram']==true)
	{
		echo'<td><p style="word-wrap:break-word">'.$value['device_ram'].'</p></td>'; // RAM
		if($param['SeuilCriticalRam']<=$value['device_usage_ram'])
		{
			echo'<td><p class="EventCritical_Incident" style="word-wrap:break-word">'.$value['device_usage_ram'].'%</p></td>'; // RAM usage
		}
		elseif($param['SeuilWarningRam']<=$value['device_usage_ram'])
		{
			echo'<td><p class="EventWarning_Incident" style="word-wrap:break-word">'.$value['device_usage_ram'].'%</p></td>'; // RAM usage
		}
		else
		{
			echo'<td><p style="word-wrap:break-word">'.$value['device_usage_ram'].'%</p></td>'; // RAM usage
		}
	}
	if($param['affiche_stockage']==true)
	{
		echo'<td><p style="word-wrap:break-word">'.$value['device_stockage'].'</p></td>'; // Stockage Total
		echo '<td>';
		if(!empty($value['device_stockage_installe']))
		{
			foreach ($value['device_stockage_installe'] as $val)
			{
				echo'<p style="word-wrap:break-word">'.$val.'</p>';
			}
		}
		echo '</td>';

		echo '<td>';
		$i=0;
		if(!empty($value['device_stockage_usage']))
		{
			foreach ($value['device_stockage_usage'] as $val)
			{
				$disk=$value['stockage_name'][$i];
				if($param['SeuilCriticalStorage']<=$val['hdd'])
				{
					echo'<p class="EventCritical_Incident" style="word-wrap:break-word">'.$disk.''.$val['hdd'].'%</p>'; // Stockage usage
				}
				elseif($param['SeuilWarningStorage']<=$val['hdd'])
				{
					echo'<p class="EventWarning_Incident" style="word-wrap:break-word">'.$disk.''.$val['hdd'].'%</p>'; // Stockage usage
				}
				else
				{
					echo'<p style="word-wrap:break-word">'.$disk.''.$val['hdd'].'%</p>'; // Stockage usage
				}
				$i++;
			}
		}
		echo '</td>';
	}
	if($param['affiche_espaceLibre']==true)
	{
		echo '<td>';
		$i=0;
		if(!empty($value['device_stockage_usage']))
		{
			foreach ($value['device_stockage_usage'] as $val)
			{
				$disk=$value['stockage_name'][$i];
				//echo $val['total']-$val['used'];
				$free = Convert\bytes($val['total']-$val['used']);
				echo'<p style="word-wrap:break-word">'.$free['value'].' '.$free['unity'].'</p>'; // Stockage usage
				$i++;
			}
		}
		echo '</td>';
	}
	echo '</tr>';
}

/**
 @brief retourne la valeur en % moyenne du service
 @detail retourne en pourcentage la valeur du service
 @params int $service_id l'identifiant du service
 @params string $interval nombre de jour de décalage (ex: -30d)
 @params string $dateFin Soit N si c'est aujourd'hui ou alors -'x'd  (x = valeur nombre de jour)
 @params string $rrdpath path pour les rrd
 @retval	int la valeur du service (%)
 @throw void
 */

function average_service($dbconnection,$service_id,$interval,$dateFin,$rrdpath)
{
	$query= $dbconnection->prepare("SELECT service_id,service_name,service_parameter,service_last_stdout,device_name,plugin_name,
								rrd_type,rrd_regex,rrd_time,rrd_name,rrd_max,rrd_min,rrd_vertical_label,rrd_graph_color,rrd_graph_type,rrd_regex_threshold,rrd_graph_num,rra_file_path
							FROM esia_services
							JOIN esia_service_rra_file ON service_id = rra_service_id
							JOIN esia_device ON device_id = service_device_id
							JOIN esia_plugins ON plugin_id = service_plugin_id
							JOIN rrd_plugins ON rrd_plugin_id=service_plugin_id WHERE service_id=?
							ORDER BY rra_graph_num NULLS FIRST,rrd_graph_type,rrd_name;");
	$ret = $query->execute(array($service_id));
	if($ret===false)
	{
		$err = $query->errorInfo();
		echo "DB error: ".$err[2]."\n";
	}
	$arr_rrd=$query->fetchAll(PDO::FETCH_OBJ);
	//liste les information pour générer le graphique et les sépares suivant leurs numéros (clé rrd_graph_num)
	$list_file=array();
	$data = array();
	foreach($arr_rrd as $row)
	{
		$filename = RRA_DIRECTORY.$row->rra_file_path;
		if(is_file($filename) && !in_array($filename, $list_file))
		{
			$list_file[]=$filename;
			$ret = rrd_fetch($filename, array( "AVERAGE", "--start",$interval, "--end",$dateFin));
			if(preg_match('#STORAGE#',$row->plugin_name))
			{
				foreach($ret['data'] as $key => $rrddata)
				{
					$flag = false;
					$val = '';
					while($flag == false && ($value = array_pop($rrddata))!==NULL )
					{
						if(stristr($value,'NAN')==FALSE)
						{
							$flag ==true;
							$val =  floatval($value);
						}
					}
					$data[strtolower($key)]=round($val,1);
				}
			}
			else
			{
				
				foreach($ret['data'] as $key => $rrddata)
				{
					$i=0;
					$avg=0;
					foreach($rrddata as $value)
					{
						if(stristr($value,'NAN')==FALSE)
						{

							$avg = $avg + floatval($value);
							$i++;
						}
					}
					if($i !=0)
					{
						$avg=round($avg/$i,2);
					}
					else
					{
						$avg='';
					}
					$data[strtolower($key)]=$avg;
				}
				
			}
		}
	}
	return $data;
}
?>
