#!/usr/bin/perl -w 

use Getopt::Long;
use strict;
use warnings;
use utf8; 
use Encode qw(encode decode);
use MIME::QuotedPrint;	
use Archive::Zip qw( :ERROR_CODES :CONSTANTS );
use MIME::Lite;
use Net::SMTPS;
use Net::SMTP::SSL;
use File::Find;

#
#MAIN
#

my $user;
my $to;
my $subject;
my $password;
my $host;
my $file;
my $path;
my $from;
my $data;
my $ssl;
my $port;
my $fsize;
my $sizemax = 5000000;

&Getopt::Long::config('bundling');
GetOptions(
	"U=s" => \$user,	"user=s" => \$user,
	"T=s" => \$to,	"to=s" => \$to,
	"s=s" => \$subject,	"subject=s" => \$subject,
	"P=s" => \$password,"password=s" => \$password,
	"H=s" => \$host,"host=s" => \$host,
	"f=s" => \$file,"file=s" => \$file,
	"d=s" => \$data,"data=s" => \$data,
	"F=s" => \$path,"path=s" => \$path,
	"S=s" => \$ssl,"ssl=s" => \$ssl,
	"p=i"=>\$port,"port=i"=>\$port,
	"e=s"=>\$from,"expiditeur=s"=>\$from,
);

### Create a new multipart message
$subject = encode_qp($subject);

my $msg = MIME::Lite->new(
		From    => $from,
		To      => $to,		
 		Type    => 'text/html; charset=UTF-8',
		Encoding=> 'quoted-printable',
		Subject => "=?utf-8?Q?$subject?=",
		Data    => $data);

## ZIP
if ( length $path > 0 && length $file > 0)
{
	$fsize = (stat($path))[7]; # in bytes
	if($fsize>$sizemax)
	{
		my $zip = Archive::Zip->new();
		$file = decode_qp($file);
		$zip->addFile($path,$file);
   		
   		#Save the Zip file   		
   		if ($zip->writeToFileNamed('/usr/local/esia/public_html/plugin/report/report.zip') != AZ_OK)
   		{ 
    		print "Error in archive creation! \n";
		}

		$msg->attach(
	  		Type 	 =>'application/zip',
	        Path     => '/usr/local/esia/public_html/plugin/report/report.zip',
	        disposition => 'attachment',
	        Filename => 'report.zip');
	}
	else
	{		
		$msg->attach(
	  		Type 	 =>'application/pdf',
	        Path     => $path,
	        Filename => $file);
	}		
}


my $smtp='';
if($port == '587' && ($host =~ m/office365/ || $host=~m/.outlook/))
{
	my $hello = $from =~ s/@/\./r;
	print "Office365 mode\n";
	#connexion office365
	$smtp = Net::SMTPS->new(Host =>$host,Port=> $port,Hello=>$hello,Timeout => 120,doSSL => 'starttls',Debug=>0) or die "Couldn't connect to server";
}
elsif($ssl eq 'on')
{
	$smtp = Net::SMTP::SSL->new(Host => $host,Port => $port) or die "Couldn't connect to server (SSL)";
}
else
{	
	$smtp = Net::SMTP->new(Host => $host,Port => $port) or die "Couldn't connect to server";
}
if($password)
{
	$smtp->auth($user,$password);	
}

$smtp->mail($from);
$smtp->to(split(/[,;]/,$to));
$smtp->data();
$smtp->datasend($msg->as_string()."\n.\n");
$smtp->dataend();  
$smtp->quit;
if($fsize>$sizemax)
{
	system('rm /usr/local/esia/public_html/plugin/report/report.zip');
}
